==> custom_pages-v1.12.7.zip: custom_pages/messages/it/model.php <==
<?php

return [
    'Abstract' => 'Abstract',
    'Activate PHP based Pages and Snippets' => 'Attiva Pagine e Sippets basati su PHP',
    'Attach Files' => 'Allega file',
    'Content' => 'Contenuto',
    'Empty <br />Container' => 'Container <br />Vuoto',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Se disattivato, le pagine php esistenti resteranno online ma non potranno essere create.',
    'Label' => 'Etichetta',
    'Open in new window' => 'Apri in una nuova finestra',
    'PHP view path for custom space pages' => 'Percorso delle view PHP per pagine personalizzate degli spazi ',
    'PHP view path for custom space snippets' => 'Percorso delle view PHP per pagine personalizzate degli snippet degli spazi ',
    'PHP view path for global custom pages' => 'Percorso delle view PHP per pagine personalizzate globali',
    'PHP view path for global custom snippets' => 'Percorso delle view PHP per pagine personalizzate degli snippet',
    'Placeholder name' => 'Nome segnaposto',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Il nome dell\'elemento deve contenere almeno due caratteri senza spazi o segni speciali ad eccezione di "_"',
    'The given element name is already in use for this template.' => 'Il nome dell\'elemento specificato è già in uso per questo modello.',
    'The given view file path does not exist.' => 'Il percorso del file della view non esiste.',
    'Url shortcut' => 'Scorciatoia Url',
    'View' => 'Vista',
    'Visibility' => 'Visibilità',
    'page' => 'pagina',
    'snippet' => 'snippet',
    'Editors' => '',
    'Language-Based Visibility' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'Visible to Group Members' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/it/model.php <==
<?php

return [
    'Abstract' => 'Abstract',
    'Activate PHP based Pages and Snippets' => 'Attiva Pagine e Sippets basati su PHP',
    'Attach Files' => 'Allega file',
    'Content' => 'Contenuto',
    'Empty <br />Container' => 'Container <br />Vuoto',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Se disattivato, le pagine php esistenti resteranno online ma non potranno essere create.',
    'Label' => 'Etichetta',
    'Open in new window' => 'Apri in una nuova finestra',
    'PHP view path for custom space pages' => 'Percorso delle view PHP per pagine personalizzate degli spazi ',
    'PHP view path for custom space snippets' => 'Percorso delle view PHP per pagine personalizzate degli snippet degli spazi ',
    'PHP view path for global custom pages' => 'Percorso delle view PHP per pagine personalizzate globali',
    'PHP view path for global custom snippets' => 'Percorso delle view PHP per pagine personalizzate degli snippet',
    'Placeholder name' => 'Nome segnaposto',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Il nome dell\'elemento deve contenere almeno due caratteri senza spazi o segni speciali ad eccezione di "_"',
    'The given element name is already in use for this template.' => 'Il nome dell\'elemento specificato è già in uso per questo modello.',
    'The given view file path does not exist.' => 'Il percorso del file della view non esiste.',
    'Url shortcut' => 'Scorciatoia Url',
    'View' => 'Vista',
    'Visibility' => 'Visibilità',
    'page' => 'pagina',
    'snippet' => 'snippet',
    'Editors' => '',
    'Hide in Navigation' => '',
    'Language-Based Visibility' => '',
    'Mobile App Users' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'The element name is reserved, please choose another one.' => '',
    'Visible to Group Members' => '',
];
